@@ -1,6 +1,4 @@
-"""
-Abstraction layer to construct a workflow node using and airflow operator
-"""
+"""Abstraction layer to construct a workflow node using and airflow operator."""
 from collections.abc import Iterable
 from typing import List
 from typing import Tuple
@@ -17,9 +15,7 @@ upstreams_type_hint = Union[List[Type[TaskBase]], None, Type[TaskBase]]
 
 
 class Node:
-    """
-    Abstraction to create a node in the workflow graph as implemented by engine api (airflow)
-    """
+    """Abstraction to create a node in the workflow graph as implemented by engine api (airflow)."""
 
     def __init__(
         self,
@@ -29,6 +25,7 @@ class Node:
         task: task_type_hint,
         upstreams: upstreams_type_hint = None,
     ):
+        """Node setup."""
         # Task type checking
         upstreams = upstreams or []
         if not isinstance(upstreams, Iterable):
@@ -49,9 +46,7 @@ class Node:
 
     @property
     def operator(self) -> BashOperator:
-        """
-        Native engine node
-        """
+        """Native engine node."""
         from datetime import timedelta
         from dkist_processing_core._failure_callback import chat_ops_notification
         from functools import partial
@@ -60,6 +55,7 @@ class Node:
 
     @property
     def operator_definition(self) -> str:
+        """Airflow style command to define a bash operator."""
         return f"""BashOperator(
     task_id='{self.task.__name__}',
     bash_command='''{self._bash_script}''',
@@ -77,16 +73,12 @@ class Node:
 
     @property
     def dependencies(self) -> List[Tuple[str, str]]:
-        """
-        List of upstream, downstream task name tuples
-        """
+        """List of upstream, downstream task name tuples."""
         return [(upstream.__name__, self.task.__name__) for upstream in self.upstreams]
 
     @property
     def _bash_script(self) -> str:
-        """
-        Format bash script for the BashOperator
-        """
+        """Format bash script for the BashOperator."""
         command = f"""{self._install_command}
 {self._run_command}"""
         return self._bash_template(command)
@@ -118,7 +110,8 @@ exit $exit_code"""
     def _install_command(self) -> str:
         repo_name = self.workflow_package.split(".")[0].replace("_", "-")
         version = self.workflow_version
-        return f"python -m pip install {repo_name}=={version}"
+        return f"""python -m pip install --upgrade pip
+python -m pip install {repo_name}=={version}"""
 
     @property
     def _run_command(self) -> str:
