@@ -1,4 +1,4 @@
-"""Utilities for the build pipeline"""
+"""Utilities for the build pipeline."""
 import importlib
 from pathlib import Path
 from shutil import rmtree
@@ -17,10 +17,7 @@ __all__ = ["validate_workflows", "export"]
 
 
 def validate_workflows(workflow_package: ModuleType, export_path: Optional[Path] = None) -> None:
-    """
-    Validates that workflow engine (airflow) objects are acyclic and that
-    exported workflows compile.
-    """
+    """Validate that workflow engine (airflow) objects are acyclic and that exported workflows compile."""
     # configure export path.  Clean up after if export path not provided
     rm_export_path_after_test = not bool(export_path)
     if export_path is None:
@@ -36,9 +33,7 @@ def validate_workflows(workflow_package: ModuleType, export_path: Optional[Path]
 
 
 def export(workflow_package: ModuleType, export_path: Optional[Union[str, Path]] = None) -> None:
-    """
-    Export workflows for deployment
-    """
+    """Export workflows for deployment."""
     [w.export(export_path) for w in _extract_workflows_from_package(workflow_package)]
 
 
@@ -61,9 +56,7 @@ def _parse_unprotected_modules_names_from_package(package: ModuleType) -> List[s
 
 
 def _validate_dags(dags: List[DAG]) -> None:
-    """
-    Validate dags by ensuring they can be traversed without cycles and are syntactically correct
-    """
+    """Validate dags by ensuring they can be traversed without cycles and are syntactically correct."""
     for d in dags:
         try:
             d.topological_sort()
@@ -72,10 +65,7 @@ def _validate_dags(dags: List[DAG]) -> None:
 
 
 def _validate_workflows(workflows: List[Workflow], export_path: Path) -> None:
-    """
-    Validate workflows by ensuring their exported version compiles as python and that there
-    is at least one node
-    """
+    """Validate workflows by ensuring their exported version compiles as python and that there is at least one node."""
     for w in workflows:
         try:
             workflow_py = w.export(export_path)
