@@ -66,13 +66,15 @@ def workflow():
     category = "instrument"
     name = "calibration_name"
     version = "V6-12342"
+    tags = ["tag1", "tag2", version]
     workflow_instance = Workflow(
         process_category=category,
         process_name=name,
         workflow_version=version,
         workflow_package=__package__,
+        tags=tags,
     )
-    return workflow_instance, category, name, version
+    return workflow_instance, category, name, version, tags
 
 
 @pytest.fixture()
